searchData={"items":[{"type":"task","doc":"Task to build the tableau site","title":"mix tableau.build","ref":"Mix.Tasks.Tableau.Build.html"},{"type":"task","doc":"Starts the tableau dev server","title":"mix tableau.server","ref":"Mix.Tasks.Tableau.Server.html"},{"type":"module","doc":"","title":"Tableau","ref":"Tableau.html"},{"type":"module","doc":"* `:include_dir` - string - Directory that is just copied to the output directory. Defaults to `extra`.\n* `:out_dir` - string - The directory to output your website to. Defaults to `_site`.\n* `:timezone` - string - Timezone to use when parsing date times. Defaults to `Etc/UTC`.\n* `:base_path` - string - Development server root.  Defaults to '/'.\n* `:url` - string (required) - The URL of your website.\n* `:converters` - mapping of file extensions to converter module. Defaults to `[md: Tableau.MDExConverter]`\n* `:markdown` - keyword\n    * `:mdex` - keyword - Options to pass to `MDEx.to_html/2`","title":"Global Site Configuration - Tableau","ref":"Tableau.html#module-global-site-configuration"},{"type":"module","doc":"```elixir\n# configs/config.exs\nconfig :tableau, :config,\n  url: \"http://localhost:8080\",\n  timezone: \"America/Indiana/Indianapolis\",\n  converters: [\n    md: Tableau.MDExConverter,\n    dj: MySite.DjotConverter\n  ],\n  markdown: [\n    mdex: [\n      extension: [table: true, header_ids: \"\", tasklist: true, strikethrough: true],\n      render: [unsafe_: true],\n      features: [syntax_highlight_theme: \"kanagawa\"]\n    ]\n  ]\n```","title":"Example - Tableau","ref":"Tableau.html#module-example"},{"type":"function","doc":"Component to connect to the development server via websocket to broadcast that the page should reload.\n\nBy default, connects to `'ws://' + location.host + '/ws'`.\n\nSee `WebDevUtils.Components.live_reload/1` for configuration options.","title":"Tableau.live_reload/1","ref":"Tableau.html#live_reload/1"},{"type":"function","doc":"Convert markdown content to HTML using `MDEx.to_html!/2`.\n\nWill use the globally configured options, but you can also pass it overrides.","title":"Tableau.markdown/2","ref":"Tableau.html#markdown/2"},{"type":"module","doc":"Helper functions for Tableau documents.","title":"Tableau.Document.Helper","ref":"Tableau.Document.Helper.html"},{"type":"macro","doc":"A macro for rendering nested content within a layout.\n\nPlease see the `Tableau.Layout` docs for more info.","title":"Tableau.Document.Helper.render/1","ref":"Tableau.Document.Helper.html#render/1"},{"type":"behaviour","doc":"A tableau extension.\n\nAn extension can be used to generate other kinds of content.","title":"Tableau.Extension","ref":"Tableau.Extension.html"},{"type":"behaviour","doc":"* `:key` - The key in which the extensions configuration and data is loaded.\n* `:type` - The type of extension. See below for a description.\n* `:priority` - An integer used for ordering extensions of the same type.\n* `:enabled` - Whether or not to enable the extension. Defaults to true, and can be configured differently based on the extension.","title":"Options - Tableau.Extension","ref":"Tableau.Extension.html#module-options"},{"type":"behaviour","doc":"There are currently the following extension types:\n\n- `:pre_build` - executed before tableau builds your site and writes anything to disk.\n- `:pre_write` - executed after tableau builds your site but before it writes anything to disk.\n- `:post_write` - executed after tableau builds your site and writes everything to disk.","title":"Types - Tableau.Extension","ref":"Tableau.Extension.html#module-types"},{"type":"behaviour","doc":"Tableau pages and layouts form a DAG, a Directed Acyclic Graph, and this graph is used to build each page when writing to disk.\n\nYour extension can create data to insert into the site token and can also inserted pages into the graph to be written to disk when the time comes.","title":"The Graph - Tableau.Extension","ref":"Tableau.Extension.html#module-the-graph"},{"type":"behaviour","doc":"In this example, we create a simple post extension that reads markdown files from disk, inserts them into the graph, and inserts them into the token.\n\nBy inserting them into the token, you are able to access them inside your templates, for example, a posts listing page.\n\n```elixir\ndefmodule MySite.PostsExtension do\n  use Tableau.Extension, key: :posts, type: :pre_build, priority: 300\n\n  def run(token) do\n    posts = \n      for post <- Path.wildcard(\"_posts/**/*.md\") do\n        %Tableau.Page{\n          parent: MySite.RootLayout,\n          permalink: Path.join(\"posts\", Path.rootname(post)),\n          template: Markdown.render(post),\n          opts: %{}\n        }\n      end\n\n    graph = Tableau.Graph.insert(token.graph, posts)\n\n    {:ok,\n     token\n     |> Map.put(:posts, posts)\n     |> Map.put(:graph, graph)}\n  end\nend\n```","title":"Example - Tableau.Extension","ref":"Tableau.Extension.html#module-example"},{"type":"callback","doc":"Optional callback to validate the config for an extension. Useful for \nproviding more useful error messages for misconfigurations.","title":"Tableau.Extension.config/1","ref":"Tableau.Extension.html#c:config/1"},{"type":"callback","doc":"The extension entry point.\n\nThe function is passed a token and can return a new token with new data loaded into it.","title":"Tableau.Extension.run/1","ref":"Tableau.Extension.html#c:run/1"},{"type":"type","doc":"","title":"Tableau.Extension.token/0","ref":"Tableau.Extension.html#t:token/0"},{"type":"behaviour","doc":"A tableau layout.\n\nLayouts will render `@inner_content` using the `Tableau.Document.Helper.render/1` macro.\n\n```elixir\ndefmodule MySite.SidebarLayout do\n  use Tableau.Page,\n    layout: MySite.RootLayout\n\n  def template(assigns) do\n    \"\"\"\n     \n       \n       \n     \n\n     \n      <%= render @inner_content %>\n     \n    \"\"\"\n  end\nend\n```","title":"Tableau.Layout","ref":"Tableau.Layout.html"},{"type":"type","doc":"","title":"Tableau.Layout.assigns/0","ref":"Tableau.Layout.html#t:assigns/0"},{"type":"type","doc":"","title":"Tableau.Layout.template/0","ref":"Tableau.Layout.html#t:template/0"},{"type":"callback","doc":"The layout template.","title":"Tableau.Layout.template/1","ref":"Tableau.Layout.html#c:template/1"},{"type":"behaviour","doc":"A tableau page.\n\nA page is a basic unit of a static site.\n\n```elixir\ndefmodule MySite.HomePage do\n  use Tableau.Page,\n    layout: MySite.RootLayout,\n    permalink: \"/\"\n\n  def template(assigns) do\n    \"\"\"\n     My Site \n\n     \n      Welcome to my site!\n     \n    \"\"\"\n  end\nend\n```","title":"Tableau.Page","ref":"Tableau.Page.html"},{"type":"function","doc":"The page struct allows you to create pages as data structures and manually insert them into the Graph.","title":"Tableau.Page.__struct__/0","ref":"Tableau.Page.html#__struct__/0"},{"type":"type","doc":"","title":"Tableau.Page.assigns/0","ref":"Tableau.Page.html#t:assigns/0"},{"type":"type","doc":"","title":"Tableau.Page.template/0","ref":"Tableau.Page.html#t:template/0"},{"type":"callback","doc":"The page template.","title":"Tableau.Page.template/1","ref":"Tableau.Page.html#c:template/1"},{"type":"behaviour","doc":"Defines the interface for the converter module used by extensions to parse markup files.","title":"Tableau.Converter","ref":"Tableau.Converter.html"},{"type":"callback","doc":"Converts content into HTML.\n\nIs given the file path, the content of the files (sans front matter), the front matter, and a list of options.","title":"Tableau.Converter.convert/4","ref":"Tableau.Converter.html#c:convert/4"},{"type":"module","doc":"Converter to parse markdown content with `MDEx`","title":"Tableau.MDExConverter","ref":"Tableau.MDExConverter.html"},{"type":"function","doc":"","title":"Tableau.MDExConverter.convert/4","ref":"Tableau.MDExConverter.html#convert/4"},{"type":"module","doc":"YAML files and Elixir scripts (.exs) in the configured directory will be automatically parsed/executed and made available in an `@data` assign in your templates.\n\nElixir scripts will be executed and the last expression returned as the data.","title":"Tableau.DataExtension","ref":"Tableau.DataExtension.html"},{"type":"module","doc":"- `:enabled` - boolean - Extension is active or not.\n- `:dir` - string - Directory to scan for data files. Defaults to `_data`","title":"Configuration - Tableau.DataExtension","ref":"Tableau.DataExtension.html#module-configuration"},{"type":"module","doc":"```elixir\nconfig :tableau, Tableau.DataExtension,\n  enabled: true,\n  dir: \"_facts\"\n```\n\n<!-- tabs-open -->","title":"Example - Tableau.DataExtension","ref":"Tableau.DataExtension.html#module-example"},{"type":"module","doc":"```yaml\n# _facts/homies.yaml\n- name: Mitch\n- name: Jimbo\n- name: Bobby\n```\n\n```heex\n \n   \n    <%= homie.name %>\n   \n \n```","title":"YAML - Tableau.DataExtension","ref":"Tableau.DataExtension.html#module-yaml"},{"type":"module","doc":"```elixir\n# _facts/homies.exs\nresp = Req.get!(\"https://example.com/homies\")\n\nresp.body[\"homies\"]\n```\n\n```heex\n \n   \n    <%= homie.name %>\n   \n \n```\n\n<!-- tabs-close -->","title":"Elixir - Tableau.DataExtension","ref":"Tableau.DataExtension.html#module-elixir"},{"type":"function","doc":"","title":"Tableau.DataExtension.config/1","ref":"Tableau.DataExtension.html#config/1"},{"type":"function","doc":"","title":"Tableau.DataExtension.run/1","ref":"Tableau.DataExtension.html#run/1"},{"type":"module","doc":"Content files (with YAML frontmatter) in the configured pages directory will be automatically compiled into Tableau pages.\n\nCertain frontmatter keys are required and all keys are passed as options to the `Tableau.Page`.","title":"Tableau.PageExtension","ref":"Tableau.PageExtension.html"},{"type":"module","doc":"Frontmatter is compiled with `yaml_elixir` and all keys are converted to atoms.\n\n* `:title` - The title of the page\n* `:permalink` - The permalink of the page.\n* `:layout` - A string representation of a Tableau layout module.\n* `:converter` - A string representation of a converter module. (optional)","title":"Options - Tableau.PageExtension","ref":"Tableau.PageExtension.html#module-options"},{"type":"module","doc":"```yaml\nid: \"GettingStarted\"\ntitle: \"Getting Started\"\npermalink: \"/docs/:title\"\nlayout: \"ElixirTools.PageLayout\"\nconverter: \"MyConverter\"\n```","title":"Example - Tableau.PageExtension","ref":"Tableau.PageExtension.html#module-example"},{"type":"module","doc":"The permalink is a string with colon prefixed template variables.\n\nThese variables will be swapped with the corresponding YAML Frontmatter key, with the result being piped through `to_string/1`.","title":"Permalink - Tableau.PageExtension","ref":"Tableau.PageExtension.html#module-permalink"},{"type":"module","doc":"- `:enabled` - boolean - Extension is active or not.\n- `:dir` - string - Directory to scan for markdown files. Defaults to `_pages`\n- `:permalink` - string - Default output path for pages. Accepts `:title` as a replacement keyword, replaced with the page's provided title. If a page has a `:permalink` provided, that will override this value _for that page_.\n- `:layout` - string - Elixir module providing page layout for pages. Default is nil.","title":"Configuration - Tableau.PageExtension","ref":"Tableau.PageExtension.html#module-configuration"},{"type":"module","doc":"```elixir\nconfig :tableau, Tableau.PageExtension,\n  enabled: true,\n  dir: \"_docs\",\n  permalink: \"/docs/:title\",\n  layout: \"MyApp.PageLayout\"\n```","title":"Example - Tableau.PageExtension","ref":"Tableau.PageExtension.html#module-example"},{"type":"module","doc":"If you're interested in authoring your content in something other than markdown (or you want to use a different markdown parser), you can configure\na converter for your format in the global configuration.\n\nCurrently the `Tableau.MDExConverter` is the only builtin converter, but you are free to write your own!\n\n```elixir\n# configs/config.exs\nconfig :tableau, :config,\n  converters: [\n    md: Tableau.MDExConverter,\n    adoc: MySite.AsciiDocConverter\n  ],\n```\n\nAs noted above, a converter can be overridden on a specific page, using the frontmatter `:converter` key.","title":"Content formats - Tableau.PageExtension","ref":"Tableau.PageExtension.html#module-content-formats"},{"type":"function","doc":"","title":"Tableau.PageExtension.config/1","ref":"Tableau.PageExtension.html#config/1"},{"type":"function","doc":"","title":"Tableau.PageExtension.run/1","ref":"Tableau.PageExtension.html#run/1"},{"type":"module","doc":"Content files (with YAML frontmatter) in the configured posts directory will be automatically compiled into Tableau pages.\n\nCertain frontmatter keys are required and all keys are passed as options to the `Tableau.Page`.","title":"Tableau.PostExtension","ref":"Tableau.PostExtension.html"},{"type":"module","doc":"Frontmatter is compiled with `yaml_elixir` and all keys are converted to atoms.\n\n* `:title` - The title of the post.\n* `:permalink` - The permalink of the post. `:title` will be replaced with the posts title and non alphanumeric characters removed. Optional.\n* `:date` - A string representation of an Elixir `NaiveDateTime`, often presented as a `sigil_N`. This will be converted to your configured timezone.\n* `:layout` - A string representation of a Tableau layout module.\n* `:converter` - A string representation of a converter module. (optional)","title":"Options - Tableau.PostExtension","ref":"Tableau.PostExtension.html#module-options"},{"type":"module","doc":"```yaml\nid: \"Update.Volume3\"\ntitle: \"The elixir-tools Update Vol. 3\"\npermalink: \"/news/:title\"\ndate: \"~N[2023-09-19 01:00:00]\"\nlayout: \"ElixirTools.PostLayout\"\nconverter: \"MyConverter\"\n```","title":"Example - Tableau.PostExtension","ref":"Tableau.PostExtension.html#module-example"},{"type":"module","doc":"The permalink is a string with colon prefixed template variables.\n\nThese variables will be swapped with the corresponding YAML Frontmatter key, with the result being piped through `to_string/1`.\n\nIn addition, there are `:year`, `:month`, and `:day` template variables.","title":"Permalink - Tableau.PostExtension","ref":"Tableau.PostExtension.html#module-permalink"},{"type":"module","doc":"- `:enabled` - boolean - Extension is active or not.\n- `:dir` - string - Directory to scan for markdown files. Defaults to `_posts`\n- `:future` - boolean - Show posts that have dates later than the current timestamp, or time at which the site is generated.\n- `:permalink` - string - Default output path for posts. Accepts `:title` as a replacement keyword, replaced with the post's provided title. If a post has a `:permalink` provided, that will override this value _for that post_.\n- `:layout` - string - Elixir module providing page layout for posts. Default is nil","title":"Configuration - Tableau.PostExtension","ref":"Tableau.PostExtension.html#module-configuration"},{"type":"module","doc":"```elixir\nconfig :tableau, Tableau.PostExtension,\n  enabled: true,\n  dir: \"_articles\",\n  future: true,\n  permalink: \"/articles/:year/:month/:day/:title\",\n  layout: \"MyApp.PostLayout\"\n```","title":"Example - Tableau.PostExtension","ref":"Tableau.PostExtension.html#module-example"},{"type":"module","doc":"If you're interested in authoring your content in something other than markdown (or you want to use a different markdown parser), you can configure\na converter for your format in the global configuration.\n\nCurrently the `Tableau.MDExConverter` is the only builtin converter, but you are free to write your own!\n\n```elixir\n# configs/config.exs\nconfig :tableau, :config,\n  converters: [\n    md: Tableau.MDExConverter,\n    adoc: MySite.AsciiDocConverter\n  ],\n```\n\nAs noted above, a converter can be overridden on a specific page, using the frontmatter `:converter` key.","title":"Content formats - Tableau.PostExtension","ref":"Tableau.PostExtension.html#module-content-formats"},{"type":"type","doc":"","title":"Tableau.PostExtension.post/0","ref":"Tableau.PostExtension.html#t:post/0"},{"type":"module","doc":"Generate one or more RSS feeds.","title":"Tableau.RSSExtension","ref":"Tableau.RSSExtension.html"},{"type":"module","doc":"Configuration is a keyword list of configuration lists with the key being the name of the XML file to be generated.\n\n- `:enabled` - boolean - Extension is active or not.\n- `:title` - string (required) - Title of your feed.\n- `:description` - string (required) - Description of your feed.\n- `:language` - string - Language to use in the ` ` tag. Defaults to \"en-us\".\n- `:include` - keyword list - List of front matter keys and values to include in the feed. If a post has any value in the list, it'll be included. Defaults to including everything.\n- `:exclude` - keyword list - List of front matter keys and values to exclude from the feed. If a post has any value in the list, it'll be included. Defaults to not excluding anything.","title":"Configuration - Tableau.RSSExtension","ref":"Tableau.RSSExtension.html#module-configuration"},{"type":"module","doc":"```elixir\nconfig :tableau, Tableau.RSSExtension,\n  enabled: true,\n  feeds: [\n    super: [\n      enabled: true,\n      language: \"pt-BR\",\n      title: \"The Super Feed\",\n      description: \"Includes all posts on the site\"\n    ],\n    posts: [\n      enabled: true,\n      language: \"pt-BR\",\n      title: \"My Elixir Devlog\",\n      description: \"My Journey on Becoming the Best Elixirist\",\n      exclude: [category: \"til\"] # excludes posts with this category\n    ],\n    til: [\n      enabled: true,\n      language: \"en-US\",\n      title: \"Today I Learned\",\n      description: \"Short log of what I learn every day\",\n      include: [category: \"til\"]\n    ]\n  ]\n```","title":"Example - Tableau.RSSExtension","ref":"Tableau.RSSExtension.html#module-example"},{"type":"module","doc":"Generate a sitemap.xml for your site, for improved search-engine indexing.","title":"Tableau.SitemapExtension","ref":"Tableau.SitemapExtension.html"},{"type":"module","doc":"- `:enabled` - boolean - Extension is active or not.","title":"Configuration - Tableau.SitemapExtension","ref":"Tableau.SitemapExtension.html#module-configuration"},{"type":"module","doc":"```elixir\nconfig :tableau, Tableau.SitemapExtension,\n  enabled: true,\n```","title":"Example - Tableau.SitemapExtension","ref":"Tableau.SitemapExtension.html#module-example"},{"type":"module","doc":"Any page may add attributes to its sitemap ` ` entry by adding a `sitemap` entry, with a map of elements to add","title":"Custom attributes - Tableau.SitemapExtension","ref":"Tableau.SitemapExtension.html#module-custom-attributes"},{"type":"module","doc":"```yaml\ntitle: \"Some Page\"\nsitemap:\n  priority: 0.8\n  changefreq: hourly\n```","title":"Frontmatter - Tableau.SitemapExtension","ref":"Tableau.SitemapExtension.html#module-frontmatter"},{"type":"module","doc":"```elixir\ndefmodule MySite.AboutPage do\n  use Tableau.Page,\n    layout: MySite.RootLayout,\n    permalink: \"/about\",\n    sitemap: %{priority: 0.8, changefreq: \"monthly\"}\n\n  # ...\nend\n```\n\nGenerated sitemap is stored in the root of your site, at /sitemap.xml.\n\nFor more information about sitemaps, see  .","title":"Tableau.Page - Tableau.SitemapExtension","ref":"Tableau.SitemapExtension.html#module-tableau-page"},{"type":"function","doc":"","title":"Tableau.SitemapExtension.run/1","ref":"Tableau.SitemapExtension.html#run/1"},{"type":"module","doc":"Creates pages for tags found in posts created by the `Tableau.PostExtension`.\n\nThe `:tags` key provided on every page in the assigns is described by `t:tags/0`.\n\nThe `@page` assign passed to the `layout` provided in the configuration is described by `t:page/0`.","title":"Tableau.TagExtension","ref":"Tableau.TagExtension.html"},{"type":"module","doc":"- `:enabled` - boolean - Extension is active or not.\n* `:layout` - module - The `Tableau.Layout` implementation to use.\n* `:permalink` - string - The permalink prefix to use for the tag page, will be joined with the tag name.","title":"Configuration - Tableau.TagExtension","ref":"Tableau.TagExtension.html#module-configuration"},{"type":"module","doc":"To take advantage of tag extension, you'll need to define a layout that will render each \"tag page\" and a normal `Tableau.Page` that lists all tags on your site.","title":"Layout and Page - Tableau.TagExtension","ref":"Tableau.TagExtension.html#module-layout-and-page"},{"type":"module","doc":"```elixir\ndefmodule MySite.TagLayout do\n  use Tableau.Layout, layout: MySite.RootLayout\n\n  def template(assigns) do\n    ~H\"\"\"\n     \n       Tag: #{@page.tag} \n\n       \n         \n            {post.title} \n         \n       \n     \n    \"\"\"\n  end\nend\n```","title":"Layout to render a tag page - Tableau.TagExtension","ref":"Tableau.TagExtension.html#module-layout-to-render-a-tag-page"},{"type":"module","doc":"This example page shows listing all takes, sorting them by the number of posts for each tag.\n\n```elixir\ndefmodule MySite.TagPage do\n  use Tableau.Page,\n    layout: MySite.RootLayout,\n    permalink: \"/tags\",\n    title: \"Tags\"\n\n\n  def template(assigns) do\n    sorted_tags = Enum.sort_by(assigns.tags, fn {_, p} -> length(p) end, :desc)\n    assigns = Map.put(assigns, :tags, sorted_tags)\n\n    ~H\"\"\"\n     \n       Tags \n\n       \n         \n           tag.tag \n\n           - {length(posts)} \n         \n       \n     \n    \"\"\"\n  end\nend\n```","title":"Page to render all tags - Tableau.TagExtension","ref":"Tableau.TagExtension.html#module-page-to-render-all-tags"},{"type":"type","doc":"","title":"Tableau.TagExtension.page/0","ref":"Tableau.TagExtension.html#t:page/0"},{"type":"type","doc":"","title":"Tableau.TagExtension.tag/0","ref":"Tableau.TagExtension.html#t:tag/0"},{"type":"type","doc":"","title":"Tableau.TagExtension.tags/0","ref":"Tableau.TagExtension.html#t:tags/0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}